# Pelyx

Pelyx is a terminal editor written in Python. It plans to be a modal editor just like vi/vim/neovim/helix. This is a personal project just for learning and enjoyment.

Pelyx is built on [Textual](https://textual.textualize.io/), so it can run on different platforms including Linux, MacOS, Windows 10/11.

This project is open-sourced under MulanPSL-2.0.

## RoadMap

Pelyx is still under developing. Here is the roadmap towards version 0.1.0.

- [x] v0.0.1: Packaging.
- [x] v0.0.2: Run a textual application.
- [ ] v0.0.3: Change to a customized text-area widget, simply display text.
- [ ] v0.0.4: Support moving around files.
- [ ] v0.0.5: Support multiple windows.
- [ ] v0.0.6: Build a framework for user configuration.
- [ ] v0.0.7: Add normal mode, insert mode, support saving modification.
- [ ] v0.0.8: Add undo and redo.
- [ ] v0.1.0: Add documentation, test for stability.
